@@ -18,10 +18,12 @@
 #
 # This translation was updated for Oddmuse 1.354.
 #
-$ModulesDescription .= '<p>$Id: bulgarian-utf8.pl,v 1.8 2006/05/10 22:52:16 as Exp $</p>';
+$ModulesDescription .= '<p>$Id: bulgarian-utf8.pl,v 1.9 2006/08/18 22:46:10 as Exp $</p>';
 %Translate = split(/\n/,<<END_OF_TRANSLATION);
 Reading not allowed: user, ip, or network is blocked.
 Не е разрешено четенето: блокиран потребител, IP адрес или мрежа.
+%s calls
+
 Could not create %s
 Не може да се създаде %s
 Invalid UserName %s: not saved.
@@ -32,6 +34,14 @@ This page contains an uploaded file:
 
 Recursive include of %s!
 
+Clear Cache
+
+Main lock obtained.
+Защита: придобиване на изключителни права.
+Main lock released.
+Премахване на защитата.
+Comments on this page
+Коментари към тази страница
 XML::RSS is not available on this system.
 Модулът XML::RSS не е инсталиран на тази система.
 diff
@@ -74,14 +84,6 @@ Preview only, not yet saved
 Предварителен преглед, още не е записано
 Please go on to %s.
 Моля продължи на %s.
-Could not open %s log file
-Не може да се отвори лог-файла: %s
-Error was
-Грешката бе
-Note: This error is normal if no changes have been made.
-Забележка: Тази грешка е нормална, ако не са направени промени.
-Could not open old %s log file
-Не може да се отвори стария лог-файл: %s
 No updates since %s
 Няма промени от %s насам
 Updates since %s
@@ -96,6 +98,10 @@ List latest change per page only
 Показвай само последната промяна на страниците
 List all changes
 Покажи всички промени
+Skip rollbacks
+
+Include rollbacks
+
 List only major changes
 Покажи само съществените промени
 Include minor changes
@@ -132,20 +138,34 @@ History of %s
 История на %s
 Compare
 Сравни
+Deleted
+
+Mark this page for deletion
+
+No other revisions available
+
+current
+
 Revision %s
 Версия %s
-by
-от
-Rolling back changes
-Връщане на промените
+Contributors to %s
+
 Missing target for rollback.
 Липсва дата, до която да се върне.
 Target for rollback is too far back.
 Датата за връщане е прекалено стара.
+Rolling back changes
+Връщане на промените
+The two revisions are the same.
+
+Editing not allowed for %s.
+Редакция на %s не е разрешена.
 Rollback to %s
 Връщане до %s
 %s rolled back
 Промените върху %s бяха успешно върнати
+to %s
+
 Index of all pages
 Индекс на всички страници
 Wiki Version
@@ -214,6 +234,8 @@ View current revision
 Виж актуалната версия
 View all changes
 Виж всички промени
+View contributors
+
 Homepage URL:
 
 s
@@ -234,28 +256,26 @@ Validate HTML
 Проверка на HTML
 Validate CSS
 Проверка на CSS
-Difference (from revision %1 to %2)
+Last edit
+
+Difference between revision %1 and %2
 Разлики (между версия %1 и %2)
 revision %s
 версия %s
 current revision
 актуална версия
-Difference (from prior %s revision)
-Разлики (с предишната %s ревизия)
-major
-съществена
-minor
-малка
+Last major edit (%s)
+
+later minor edits
+
 No diff available.
 Не са належащи данни за разликите.
-The two revisions are the same.
-
 Old revision:
 
 Changed:
 Заместено:
-Removed:
-Изтрито:
+Deleted:
+
 Added:
 Прибавено:
 to
@@ -326,9 +346,9 @@ Summary:
 Резюме:
 This change is a minor edit.
 Това е малка промяна.
-Replace this file with text.
+Replace this file with text
 Замени този файл с текст
-Replace this text with a file.
+Replace this text with a file
 Замени този текст с файл
 File to upload: 
 Файл за качване: 
@@ -352,6 +372,10 @@ This operation is restricted to site editors only...
 Тази операция може да се извършва само от редактори.
 This operation is restricted to administrators only...
 Тази операция може да се извършва само от администратори.
+SampleUndefinedPage
+ПримерНаНедефиниранаСтраница
+Sample_Undefined_Page
+Пример_на_недефинирана_страница
 Rule "%1" matched "%2" on this page.
 
 Without normal pages
@@ -390,24 +414,8 @@ Near pages:
 Близки страници:
 last updated
 последна промяна
-Complete Content
-Пълно съдържание
-The main page is %s.
-Главната страница е %s.
-Comments on this page
-Коментари към тази страница
-Editing not allowed for %s.
-Редакция на %s не е разрешена.
-SampleUndefinedPage
-ПримерНаНедефиниранаСтраница
-%s cannot be defined.
-%s не може да се дефинира.
-Sample_Undefined_Page
-Пример_на_недефинирана_страница
-[[%s]] cannot be defined.
-[[%s]] не може да се дефинира.
-Only an administrator can create %s.
-
+by
+от
 Transfer Error: %s
 Грешка при трансфера: %s
 Browser reports no file info.
@@ -448,8 +456,6 @@ Maintenance not done.
 (Поддръжка се прави веднъж на 12 часа.)
 Remove the "maintain" file or wait.
 Изтрий файла "maintain" или изчакай.
-Main lock obtained.
-Защита: придобиване на изключителни права.
 Expiring keep files and deleting pages marked for deletion
 Триене на стари версии и страници маркирани за триене.
 not deleted: 
@@ -458,12 +464,16 @@ deleted
 Файлът бе изтрит
 Moving part of the %s log file.
 Преместване на част от лог-файла %s.
+Could not open %s log file
+Не може да се отвори лог-файла: %s
+Error was
+Грешката бе
+Note: This error is normal if no changes have been made.
+Забележка: Тази грешка е нормална, ако не са направени промени.
 Moving %s log entries.
 Преместване на %s лог-записа.
 Getting page index file for %s.
 Получаване на индекс за %s.
-Main lock released.
-Премахване на защитата.
 Set or Remove global edit lock
 Налагане или отмяна на глобална защита от редакции.
 Edit lock created.
@@ -524,6 +534,10 @@ Rename %s to:
 
 Learn more...
 
+Complete Content
+Пълно съдържание
+The main page is %s.
+Главната страница е %s.
 Cannot highlight the language %s.
 
 Recent Visitors
@@ -774,8 +788,16 @@ Download this page as PDF
 
 Portrait
 
+Publish %s
+
+No target wiki was specified in the config file.
+
+The target wiki was misconfigured.
+
 You did not answer correctly.
 
+To save this page you must answer this question:
+
 All Referrers
 Всички линкове
 Referrers
@@ -800,6 +822,12 @@ Result pages:
 
 (%s results)
 
+Tags:
+
+Tags: %s.
+
+No tags
+
 Slideshow:%s
 
 Static Copy
@@ -854,6 +882,12 @@ http://www.pricescan.com/books/BookDetail.asp?isbn=%s
 http://www.pricescan.com/books/BookDetail.asp?isbn=%s
 search
 търси
+Wanted Pages
+
+%s pages
+
+%s, referenced from:
+
 Upload of %s file
 
 Blog
@@ -864,4 +898,8 @@ New
 
 Edit %s.
 
+Title: 
+
+Tags: 
+
 END_OF_TRANSLATION
