@@ -17,9 +17,9 @@
 #    59 Temple Place, Suite 330
 #    Boston, MA 02111-1307 USA
 
-$ModulesDescription .= '<p>$Id: sidebar.pl,v 1.15 2006/07/15 23:15:12 as Exp $</p>';
+$ModulesDescription .= '<p>$Id: sidebar.pl,v 1.16 2006/08/06 23:18:08 as Exp $</p>';
 
-use vars qw($SidebarName);
+use vars qw($SidebarName $SideBarOpenPageName);
 
 # Include this page on every page:
 
@@ -40,8 +40,15 @@ sub SidebarInit {
 sub NewSideBarGetHeader {
   my ($id) = @_;
   print OldSideBarGetHeader(@_);
+  # While rendering, OpenPageName must point to the sidebar, so that
+  # the form extension which checks whether the current page is locked
+  # will check the SideBar lock and not the real page's lock.
+  # On the other hand, when the sidebar contains a <toc>, the
+  # generated toc should point to the headers of the real page.
+  local $SideBarOpenPageName = $OpenPageName;
   local $OpenPageName = $SidebarName;
   print '<div class="sidebar">';
+  # This makes sure that $Page{text} remains undisturbed.
   PrintWikiToHTML(GetPageContent($SidebarName));
   print '</div>';
   return '';
